@@ -2,7 +2,7 @@
 
 # Configuration
 gameMusic = False
-gameSound = True
+gameSound = False
 player_speed = 8
 enemy_speed = 6
 players = 1
