@@ -13,8 +13,7 @@ from util import algorithms
 import constants
 import config
 import basicSprite
-import greenManSprite
-import purpleManSprite
+import playerSprite
 import basicMonster
 import item_cache
 import helpers
@@ -45,6 +44,16 @@ class LevelView(object):
 	def __init__(self, dataPath, width=800, height=480):
 		self._dataPath = dataPath
 		self._cache = item_cache.ItemCache()
+		self._inputMapping = {
+			pygame.locals.K_UP: (lambda: self.greenMan, playerSprite.DIRECTION_UP),
+			pygame.locals.K_DOWN: (lambda: self.greenMan, playerSprite.DIRECTION_DOWN),
+			pygame.locals.K_LEFT: (lambda: self.greenMan, playerSprite.DIRECTION_LEFT),
+			pygame.locals.K_RIGHT: (lambda: self.greenMan, playerSprite.DIRECTION_RIGHT),
+			pygame.locals.K_e: (lambda: self.purpleMan, playerSprite.DIRECTION_UP),
+			pygame.locals.K_c: (lambda: self.purpleMan, playerSprite.DIRECTION_DOWN),
+			pygame.locals.K_s: (lambda: self.purpleMan, playerSprite.DIRECTION_LEFT),
+			pygame.locals.K_f: (lambda: self.purpleMan, playerSprite.DIRECTION_RIGHT),
+		}
 
 		try:
 			pygame.mixer.pre_init(44100, -16, 1, 256)
@@ -81,8 +90,6 @@ class LevelView(object):
 			config.players = levels[0].parent.parent.playerCount
 			config.greenScore = 0
 			config.purpleScore = 0
-			config.greenHits = 0
-			config.purpleHits = 0
 			config.greenScore = 0
 			config.purpleScore = 0
 
@@ -100,6 +107,9 @@ class LevelView(object):
 						break
 					config.levelselect += 1
 					nextLevel.mark_available()
+					config.greenHitsTotal += self.greenMan.hits
+					if config.players == 2:
+						config.purpleHitsTotal += self.purpleMan.hits
 				elif transition == self._REPEAT_LEVEL:
 					pass
 				elif transition == self._QUIT:
@@ -138,21 +148,11 @@ class LevelView(object):
 			if event.type == pygame.QUIT:
 				sys.exit()
 			elif event.type == pygame.locals.KEYDOWN:
-				if event.key in (
-					pygame.locals.K_RIGHT,
-					pygame.locals.K_LEFT,
-					pygame.locals.K_UP,
-					pygame.locals.K_DOWN,
-				):
-					self.greenMan.MoveKeyDown(event.key)
-				elif event.key in (
-					pygame.locals.K_f,
-					pygame.locals.K_s,
-					pygame.locals.K_e,
-					pygame.locals.K_c,
-				):
-					if config.players == 2:
-						self.purpleMan.MoveKeyDown(event.key)
+				if event.key in self._inputMapping:
+					target, targetEvent = self._inputMapping[event.key]
+					target = target()
+					if target is not None:
+						target.MoveKeyDown(targetEvent)
 				elif event.key == pygame.locals.K_p:
 					screenshotPath = os.path.expanduser("~/MyDocs/omnom")
 					try:
@@ -168,31 +168,21 @@ class LevelView(object):
 				elif event.key == pygame.locals.K_BACKSPACE:
 					return self._QUIT
 			elif event.type == pygame.locals.KEYUP:
-				if event.key in (
-					pygame.locals.K_RIGHT,
-					pygame.locals.K_LEFT,
-					pygame.locals.K_UP,
-					pygame.locals.K_DOWN,
-				):
-					self.greenMan.MoveKeyUp(event.key)
-				elif event.key in (
-					pygame.locals.K_f,
-					pygame.locals.K_s,
-					pygame.locals.K_e,
-					pygame.locals.K_c,
-				):
-					if config.players == 2:
-						self.purpleMan.MoveKeyUp(event.key)
-			elif event.type == greenManSprite.SUPER_STATE_OVER:
+				if event.key in self._inputMapping:
+					target, targetEvent = self._inputMapping[event.key]
+					target = target()
+					if target is not None:
+						target.MoveKeyUp(targetEvent)
+			elif event.type == playerSprite.SUPER_STATE_OVER:
 				for player in self._players():
 					player.superState = False
-				pygame.time.set_timer(greenManSprite.SUPER_STATE_OVER, 0)
+				pygame.time.set_timer(playerSprite.SUPER_STATE_OVER, 0)
 				for monster in self.monster_sprites.sprites():
 					monster.SetScared(False)
-			elif event.type == greenManSprite.SUPER_STATE_START:
+			elif event.type == playerSprite.SUPER_STATE_START:
 				for monster in self.monster_sprites.sprites():
 					monster.SetScared(True)
-			elif event.type == greenManSprite.PLAYER_EATEN:
+			elif event.type == playerSprite.PLAYER_EATEN:
 				self._hudNeedsUpdate = True
 				if all(player.lives < 1 for player in self._players()):
 					self.dead = True
@@ -302,8 +292,6 @@ class LevelView(object):
 			pygame.display.flip()
 
 		pygame.time.wait(1000)
-		config.greenHitsTotal = config.greenHitsTotal+config.greenHits
-		config.purpleHitsTotal = config.purpleHitsTotal+config.purpleHits
 		if config.players == 2:
 			text = font.render("%s" % (config.greenHitsTotal), 1, (255, 255, 255))
 			textpos = text.get_rect()
@@ -472,10 +460,10 @@ class LevelView(object):
 				xCenterPoint = x*blockSize + x_offset
 				centerPoint = (xCenterPoint, yCenterPoint)
 				if symbol == "G":
-					self.greenMan = greenManSprite.greenMan(centerPoint, level, self._cache)
+					self.greenMan = playerSprite.PlayerSprite(centerPoint, level, self._cache, "G")
 				elif symbol == "P":
 					if config.players == 2:
-						self.purpleMan = purpleManSprite.purpleMan(centerPoint, level, self._cache)
+						self.purpleMan = playerSprite.PlayerSprite(centerPoint, level, self._cache, "P")
 				else:
 					raise RuntimeError("Unknown map symbol %r" % symbol)
 
