@@ -7,6 +7,7 @@ from __future__ import division
 import os
 import simplejson
 import logging
+import logging.handlers
 
 from PyQt4 import QtCore
 from PyQt4 import QtGui
@@ -44,10 +45,20 @@ class Omnom(qwrappers.ApplicationWrapper):
 			settings = {}
 
 		self._fullscreenAction.setChecked(settings.get("isFullScreen", False))
+		config.gameMusic = settings.get("musicEnabled", config.gameMusic)
+		config.gameSound = settings.get("soundEffectsEnabled", config.gameSound)
+		config.lives = settings.get("startingLifeCount", config.lives)
+		config.player_speed = settings.get("playerSpeed", config.player_speed)
+		config.enemy_speed = settings.get("enemySpeed", config.enemy_speed)
 
 	def save_settings(self):
 		settings = {
 			"isFullScreen": self._fullscreenAction.isChecked(),
+			"musicEnabled": config.gameMusic,
+			"soundEffectsEnabled": config.gameSound,
+			"startingLifeCount": config.lives,
+			"playerSpeed": config.player_speed,
+			"enemySpeed": config.enemy_speed,
 		}
 		with open(constants._user_settings_, "w") as settingsFile:
 			simplejson.dump(settings, settingsFile)
@@ -228,6 +239,23 @@ class PlayerCampaignSelector(qwrappers.WindowWrapper):
 
 
 def run():
+	try:
+		os.makedirs(constants._data_path_)
+	except OSError, e:
+		if e.errno != 17:
+			raise
+
+	logFormat = '(%(relativeCreated)5d) %(levelname)-5s %(threadName)s.%(name)s.%(funcName)s: %(message)s'
+	logging.basicConfig(level=logging.DEBUG, format=logFormat)
+	rotating = logging.handlers.RotatingFileHandler(constants._user_logpath_, maxBytes=512*1024, backupCount=1)
+	rotating.setFormatter(logging.Formatter(logFormat))
+	root = logging.getLogger()
+	root.addHandler(rotating)
+	_moduleLogger.info("%s %s-%s" % (constants.__app_name__, constants.__version__, constants.__build__))
+	_moduleLogger.info("OS: %s" % (os.uname()[0], ))
+	_moduleLogger.info("Kernel: %s (%s) for %s" % os.uname()[2:])
+	_moduleLogger.info("Hostname: %s" % os.uname()[1])
+
 	app = QtGui.QApplication([])
 	handle = Omnom(app)
 	return app.exec_()
@@ -235,14 +263,5 @@ def run():
 
 if __name__ == "__main__":
 	import sys
-
-	logFormat = '(%(relativeCreated)5d) %(levelname)-5s %(threadName)s.%(name)s.%(funcName)s: %(message)s'
-	logging.basicConfig(level=logging.DEBUG, format=logFormat)
-	try:
-		os.makedirs(constants._data_path_)
-	except OSError, e:
-		if e.errno != 17:
-			raise
-
 	val = run()
 	sys.exit(val)
